# cpematcher

Match and compare CPEs.

## Installation / Usage

To install use pip:

    $ pip install cpematcher-ng

# Origin

The project was forked from [cpematcher](https://github.com/alertot/cpematcher). Kudos to the original author!

# Development

We use [devenv](https://devenv.sh) and [direnv]() for development.
You can setup virtualenvs for all supported Python versions:

```shell
$ just install-versions
```

And run all checks and tests after that:

```shell
$ just check test-all
```
